(* $Workfile:   p7.tpl  $ $Revision:   1.14  $ *)
(* P7.TPL *)
(*****************************************************************************)
(* ASN.1 P7 Data-type Template                                               *)
(*                                                                           *)
(* Known deficiencies:                                                       *)
(*    - some of the ANYs should be ANY DEFINED BYs                           *)
(*    - strong credentials not done                                          *)
(*    - responder credentials not done                                       *)
(*    - security context not done                                            *)
(*    - synopsis                                                             *)
(*    - Aextn                                                                *)
(*    - Nodes 7reqs, 7liss, 7sqss, 7pr3s, 7pr7s did have limit = 2147483647  *)
(*****************************************************************************)


(*****************************************************************************)
(* Common data-types related to the information model                        *)
(*****************************************************************************)

InformationBase            LABEL     = 7infb
                           STRUCTURE = INTEGER

SequenceNumber             LABEL     = 7seqn
                           STRUCTURE = INTEGER

Attribute                  LABEL     = 7attr
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7atty, U  6 P,M,0>*,
                                         <7atvs, U 16 C,M,0> }

AttributeType              LABEL     = 7atty
                           STRUCTURE = OBJECT IDENTIFIER

values                     LABEL     = 7atvs
                           STRUCTURE = SEQUENCE OF
                           LIMIT     = 32767
                           CHILDREN  = { <7atvl, U  0 P,O,0> }

AttributeValue             LABEL     = 7atvl
                           STRUCTURE = ANY
                           CHILDREN  = { }

SubstringAttrValue         LABEL     = 7ssvl
                           STRUCTURE = ANY
                           CHILDREN  = { }

AutoActionRegistration     LABEL     = 7aarg
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7aaty, U  6 P,M,0>*,
                                         <7rgit, C  0 C,D,0> ,
                                         <7rgpt, C  1 C,M,0> }

AutoActionType             LABEL     = 7aaty
                           STRUCTURE = OBJECT IDENTIFIER

registration-id TAG        LABEL     = 7rgit
                           STRUCTURE = TAG
                           CHILDREN  = { <7rgid, U  2 P,M,0> }

registration-id            LABEL     = 7rgid
                           STRUCTURE = INTEGER

registration-parameter TAG LABEL     = 7rgpt
                           STRUCTURE = TAG
                           CHILDREN  = { <7rgpa, U  0 P,M,0> }

registration-parameter ADB LABEL     = 7rgpa
                           STRUCTURE = ANY DEFINED BY
                           DEFGLABEL = 7aaty
                           REGISTER  = { <{2 6 4 4 0}, 7afrp, U 17 C,0> ,
                                         <{2 6 4 4 1}, 7aarp, U 17 C,0> }


(*****************************************************************************)
(* Abstract-bind                                                             *)
(*****************************************************************************)

MSBindArgument TAG         LABEL     = 7bart
                           STRUCTURE = TAG
                           TAG       = (C 16 C)
                           CHILDREN  = { <7barg, U 17 C,M,0> }

MSBindArgument             LABEL     = 7barg
                           STRUCTURE = SET
                           CHILDREN  = { <7inir, A  0 C,M,0> ,
                                         <7icrd, C  2 C,M,0> ,
                                         <7sctx, C  3 C,O,0> ,
                                         <7fres, C  4 C,O,0> ,
                                         <7cfrq, C  5 C,D,0> }

initiator                  LABEL     = 7inir
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <Dsatt, U 16 C,M,0> ,
                                         <Dddal, U 16 C,O,0> ,
                                         <Dxatl, U 17 C,O,0> ,
                                         <Ddirn, C  0 C,O,0> }

initiator-credentials      LABEL     = 7icrd
                           STRUCTURE = TAG
                           CHILDREN  = { <7cred, U  0 P,M,0> }

Credentials                LABEL     = 7cred
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7ia5s, U 22 S,O,62> ,
                                         <7octs, U  4 P,O,62> ,
                                         <7stgc, C  0 C,O,0> }

SimpleCredentials(IA5)     LABEL     = 7ia5s
                           STRUCTURE = IA5 STRING

SimpleCredentials(Octets)  LABEL     = 7octs
                           STRUCTURE = OCTETSTRING

StrongCredentials          LABEL     = 7stgc
                           STRUCTURE = ANY
                           TAG       = (C 0 C)
                           CHILDREN  = { }

security-context           LABEL     = 7sctx
                           STRUCTURE = SET OF
                           LIMIT     = 256
                           CHILDREN  = { <7mslb, U 17 C,O,0> }

security-label             LABEL     = 7mslb
                           STRUCTURE = SET
                           CHILDREN  = { <Mspid, U  6 P,O,0>,
                                         <Mscls, U  2 P,O,0>,
                                         <Mpvmk, U 19 P,O,128>,
                                         <Mscts, U 17 C,O,0> }

fetch-restrictions         LABEL     = 7fres
                           STRUCTURE = TAG
                           CHILDREN  = { <7rest, U 17 C,M,0> }

ms-configuration-request   LABEL     = 7cfrq
                           STRUCTURE = TAG
                           CHILDREN  = { <Cbool, U  1 P,M,0> }

Restrictions               LABEL     = 7rest
                           STRUCTURE = SET
                           CHILDREN  = { <7alct, C  0 C,O,0> ,
                                         <7aeit, C  1 C,O,0> ,
                                         <7mxcl, C  2 C,O,0> }

allowed-content-types      LABEL     = 7alct
                           STRUCTURE = TAG
                           CHILDREN  = { <7alcs, U 17 C,M,0> }

allowed-cont-types SET OF  LABEL     = 7alcs
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7alcn, U  6 P,O,0> }

allowed-cont-type          LABEL     = 7alcn
                           STRUCTURE = OBJECT IDENTIFIER

allowed-EITs               LABEL     = 7aeit
                           STRUCTURE = TAG
                           CHILDREN  = { <7eits, U 17 C,M,0> }

maximum-content-length     LABEL     = 7mxcl
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

MS-EITs                    LABEL     = 7eits
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7meit, U  6 P,O,0> }

MS-EIT                     LABEL     = 7meit
                           STRUCTURE = OBJECT IDENTIFIER

Single ASN.1 Type - brst   LABEL     = 7brsa
                           STRUCTURE = TAG
                           TAG       = (C 0 C)
                           CHILDREN  = { <7brst, C 17 C,M,0> }

MSBindResult TAG           LABEL     = 7brst
                           STRUCTURE = TAG
                           TAG       = (C 17 C)
                           CHILDREN  = { <7brsl, U 17 C,O,0> }

MSBindResult               LABEL     = 7brsl
                           STRUCTURE = SET
                           CHILDREN  = { <7rcrd, C  2 C,M,0> ,
                                         <7aaat, C  3 C,O,0> ,
                                         <7aatt, C  4 C,O,0> ,
                                         <7aind, C  5 C,D,0> ,
                                         <7cspt, C  6 C,O,0> }

responder-credentials      LABEL     = 7rcrd
                           STRUCTURE = TAG
                           CHILDREN  = { <7cred, U  0 P,M,0> }

avail-auto-actions TAG     LABEL     = 7aaat
                           STRUCTURE = TAG
                           CHILDREN  = { <7aaas, U 17 C,M,0> }

avail-auto-actions SET OF  LABEL     = 7aaas
                           STRUCTURE = SET OF
                           LIMIT     = 16
                           CHILDREN  = { <7aaac, U  6 P,O,0> }

avail-auto-action          LABEL     = 7aaac
                           STRUCTURE = OBJECT IDENTIFIER

avail-attr-types TAG       LABEL     = 7aatt
                           STRUCTURE = TAG
                           CHILDREN  = { <7aats, U 17 C,M,0> }

avail-attr-types SET OF    LABEL     = 7aats
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7aatr, U  6 P,O,0> }

avail-attr-type            LABEL     = 7aatr
                           STRUCTURE = OBJECT IDENTIFIER

alert-indication           LABEL     = 7aind
                           STRUCTURE = TAG
                           CHILDREN  = { <Cbool, U  1 P,M,0> }

cont-types-supped TAG      LABEL     = 7cspt
                           STRUCTURE = TAG
                           CHILDREN  = { <7csps, U 17 C,M,0> }

cont-types-supped SET OF   LABEL     = 7csps
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7ctsp, U  6 P,O,0> }

cont-types-supped          LABEL     = 7ctsp
                           STRUCTURE = OBJECT IDENTIFIER

Single ASN.1 Type - bert   LABEL     = 7bera
                           STRUCTURE = TAG
                           TAG       = (C 0 C)
                           CHILDREN  = { <7bert, C 18 C,M,0> }

MSBindError TAG            LABEL     = 7bert
                           STRUCTURE = TAG
                           TAG       = (C 18 C)
                           CHILDREN  = { <7berr, U 10 P,O,0> }

MSBindError                LABEL     = 7berr
                           STRUCTURE = ENUMERATED


(*****************************************************************************)
(* Common data-types for abstract-operations                                 *)
(*****************************************************************************)

Range                      LABEL     = 7rnge
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7seqr, C  0 C,O,0> ,
                                         <7crtr, C  1 C,O,0> }

sequence-number-range      LABEL     = 7seqr
                           STRUCTURE = TAG
                           TAG       = (C 0 C)
                           CHILDREN  = { <7numr, U 16 C,M,0> }

creation-time-range        LABEL     = 7crtr
                           STRUCTURE = TAG
                           TAG       = (C 1 C)
                           CHILDREN  = { <7timr, U 16 C,M,0> }

NumberRange                LABEL     = 7numr
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7numf, C  0 C,O,0> ,
                                         <7numt, C  1 C,O,0> }

from number TAG            LABEL     = 7numf
                           STRUCTURE = TAG
                           CHILDREN  = { <7fnum, U  2 P,M,0> }

from number                LABEL     = 7fnum
                           STRUCTURE = INTEGER

to number TAG              LABEL     = 7numt
                           STRUCTURE = TAG
                           CHILDREN  = { <7tnum, U  2 P,M,0> }

to number                  LABEL     = 7tnum
                           STRUCTURE = INTEGER

TimeRange                  LABEL     = 7timr
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7timf, C  0 C,O,0> ,
                                         <7timt, C  1 C,O,0> }

from time TAG              LABEL     = 7timf
                           STRUCTURE = TAG
                           CHILDREN  = { <7ftim, U 23 P,M,0> }

from time                  LABEL     = 7ftim
                           STRUCTURE = UTC TIME

to time TAG                LABEL     = 7timt
                           STRUCTURE = TAG
                           CHILDREN  = { <7ttim, U 23 P,M,0> }

to time                    LABEL     = 7ttim
                           STRUCTURE = UTC TIME

(* Filters (to AVA) lifted from DSADAP.TPL with minor mods                   *)

Filter(top level)          LABEL     = 7filt
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7fili, C  0 C,O,0> ,
                                         <7andt, C  1 C,O,0> ,
                                         <7orxt, C  2 C,O,0> ,
                                         <7nott, C  3 C,O,0> }

Filter(nested)             LABEL     = 7filn
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7fili, C  0 C,O,0> ,
                                         <7andt, C  1 C,O,0> ,
                                         <7orxt, C  2 C,O,0> ,
                                         <7nott, C  3 C,O,0> }

FilterItem                 LABEL     = 7fili
                           STRUCTURE = CHOICE
                           TAG       = (C 0 C)
                           CHILDREN  = { <7equa, C  0 C,O,0> ,
                                         <7sstt, C  1 C,O,0> ,
                                         <7greq, C  2 C,O,0> ,
                                         <7leeq, C  3 C,O,0> ,
                                         <7psnt, C  4 C,O,0> ,
                                         <7appm, C  5 C,O,0> }

Equal                      LABEL     = 7equa
                           STRUCTURE = TAG
                           CHILDREN  = { <7atva, U 16 C,M,0> }

Substrings TAG             LABEL     = 7sstt
                           STRUCTURE = TAG
                           CHILDREN  = { <7sstr, U 16 C,M,0> }

Substrings                 LABEL     = 7sstr
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7atty, U  6 P,M,0> ,
                                         <7strs, U 16 C,M,0> }

Strings                    LABEL     = 7strs
                           STRUCTURE = SEQUENCE OF
                           CHILDREN  = { <7strg, U  0 P,O,0> }

String                     LABEL     = 7strg
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7init, C  0 C,O,0> ,
                                         <7anyx, C  1 C,O,0> ,
                                         <7finl, C  2 C,O,0> }

Initial                    LABEL     = 7init
                           STRUCTURE = TAG
                           CHILDREN  = { <7ssvl, U  0 P,M,0> }

Any                        LABEL     = 7anyx
                           STRUCTURE = TAG
                           CHILDREN  = { <7ssvl, U  0 P,M,0> }

Final                      LABEL     = 7finl
                           STRUCTURE = TAG
                           CHILDREN  = { <7ssvl, U  0 P,M,0> }

GreaterOrEqual             LABEL     = 7greq
                           STRUCTURE = TAG
                           CHILDREN  = { <7atva, U 16 C,M,0> }

LessOrEqual                LABEL     = 7leeq
                           STRUCTURE = TAG
                           CHILDREN  = { <7atva, U 16 C,M,0> }

Present                    LABEL     = 7psnt
                           STRUCTURE = TAG
                           CHILDREN  = { <7atty, U  6 P,M,0> }

ApproximateMatch           LABEL     = 7appm
                           STRUCTURE = TAG
                           CHILDREN  = { <7atva, U 16 C,M,0> }

And TAG                    LABEL     = 7andt
                           STRUCTURE = TAG
                           CHILDREN  = { <7andx, U 17 C,M,0> }

And                        LABEL     = 7andx
                           STRUCTURE = SET OF
                           CHILDREN  = { <7filn, U  0 P,O,0> }

Or TAG                     LABEL     = 7orxt
                           STRUCTURE = TAG
                           CHILDREN  = { <7orxx, U 17 C,M,0> }

Or                         LABEL     = 7orxx
                           STRUCTURE = SET OF
                           CHILDREN  = { <7filn, U  0 P,O,0> }

Not TAG                    LABEL     = 7nott
                           STRUCTURE = TAG
                           CHILDREN  = { <7filn, U  0 P,O,0> }

AttributeValueAssertion    LABEL     = 7atva
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7atty, U  6 P,M,0>*,
                                         <7atvl, U  0 P,M,0> }

Selector                   LABEL     = 7selr
                           STRUCTURE = SET
                           CHILDREN  = { <7schi, C  0 C,D,0> ,
                                         <7srng, C  1 C,O,0> ,
                                         <7sfil, C  2 C,O,0> ,
                                         <7slim, C  3 C,O,0> ,
                                         <7sovr, C  4 C,O,0> }

child-entries              LABEL     = 7schi
                           STRUCTURE = TAG
                           CHILDREN  = { <Cbool, U  1 P,M,0> }

range                      LABEL     = 7srng
                           STRUCTURE = TAG
                           CHILDREN  = { <7rnge, U  0 P,M,0> }

filter                     LABEL     = 7sfil
                           STRUCTURE = TAG
                           CHILDREN  = { <7filt, U  0 P,M,0> }

limit TAG                  LABEL     = 7slim
                           STRUCTURE = TAG
                           CHILDREN  = { <7slmt, U  2 P,M,0> }

limit                      LABEL     = 7slmt
                           STRUCTURE = INTEGER

override                   LABEL     = 7sovr
                           STRUCTURE = TAG
                           CHILDREN  = { <Cbits, U  3 P,M,2> }

EntryInformationSelection  LABEL     = 7ents
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7atsl, U 17 C,O,0> }

AttributeSelection         LABEL     = 7atsl
                           STRUCTURE = SET
                           CHILDREN  = { <7atty, U  6 P,M,0> ,
                                         <7atsf, C  0 C,O,0> ,
                                         <7atsc, C  1 C,O,0> }

from TAG                   LABEL     = 7atsf
                           STRUCTURE = TAG
                           CHILDREN  = { <7atfm, U  2 P,M,0> }

from                       LABEL     = 7atfm
                           STRUCTURE = INTEGER

count TAG                  LABEL     = 7atsc
                           STRUCTURE = TAG
                           CHILDREN  = { <7atcn, U  2 P,M,0> }

count                      LABEL     = 7atcn
                           STRUCTURE = INTEGER

EntryInformation           LABEL     = 7enti
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7seqn, U  2 P,M,0> ,
                                         <7atts, U 17 C,O,0> }

attributes                 LABEL     = 7atts
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7attr, U 16 C,O,0> }


(*****************************************************************************)
(* Abstract-operations                                                       *)
(*****************************************************************************)

(* Summarize *)

SummarizeArgument          LABEL     = 7asum
                           STRUCTURE = SET
                           CHILDREN  = { <7ibty, C  0 C,D,0> ,
                                         <7selt, C  1 C,M,0> ,
                                         <7smrt, C  2 C,O,0> }

summary-requests TAG       LABEL     = 7smrt
                           STRUCTURE = TAG
                           CHILDREN  = { <7smrq, U 16 C,M,0> }

summary-requests SEQ OF    LABEL     = 7smrq
                           STRUCTURE = SEQUENCE OF
                           LIMIT     = 16
                           CHILDREN  = { <7rqtd, U  6 P,O,0> }

requested                  LABEL     = 7rqtd
                           STRUCTURE = OBJECT IDENTIFIER

SummarizeResult            LABEL     = 7smrs
                           STRUCTURE = SET
                           CHILDREN  = { <7next, C  0 C,O,0> ,
                                         <7coun, C  1 C,M,0> ,
                                         <7rspn, C  2 C,O,0> ,
                                         <7rsum, C  3 C,O,0> }

summaries TAG              LABEL     = 7rsum
                           STRUCTURE = TAG
                           CHILDREN  = { <7sums, U 16 C,M,0> }

summaries SEQ OF           LABEL     = 7sums
                           STRUCTURE = SEQUENCE OF
                           LIMIT     = 16
                           CHILDREN  = { <7summ, U 17 C,O,0> }

Span                       LABEL     = 7span
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7numf, C  0 C,M,0> ,
                                         <7numt, C  1 C,M,0> }

Summary                    LABEL     = 7summ
                           STRUCTURE = SET
                           CHILDREN  = { <7abst, C  0 C,O,0> ,
                                         <7prst, C  1 C,O,0> }

absent                     LABEL     = 7abst
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

present TAG                LABEL     = 7prst
                           STRUCTURE = TAG
                           CHILDREN  = { <7pset, U 17 C,M,0> }

present SET OF             LABEL     = 7pset
                           STRUCTURE = SET OF
                           LIMIT     = 32767
                           CHILDREN  = { <7pseq, U 16 C,O,0> }

present SEQUENCE           LABEL     = 7pseq
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7paty, U  6 P,M,0>*,
                                         <7pavl, U  0 P,M,0> ,
                                         <7atcn, U  2 P,M,0> }

present attribute type     LABEL     = 7paty
                           STRUCTURE = OBJECT IDENTIFIER

present attribute value    LABEL     = 7pavl
                           STRUCTURE = ANY
                           CHILDREN  = { }


(* List *)

ListArgument               LABEL     = 7alst
                           STRUCTURE = SET
                           CHILDREN  = { <7ibty, C  0 C,D,0> ,
                                         <7selt, C  1 C,M,0> ,
                                         <7rqat, C  3 C,O,0> }

ListResult                 LABEL     = 7rlst
                           STRUCTURE = SET
                           CHILDREN  = { <7next, C  0 C,O,0> ,
                                         <7reqt, C  1 C,O,0> }

requested TAG              LABEL     = 7reqt
                           STRUCTURE = TAG
                           CHILDREN  = { <7reqs, U 16 C,M,0> }

requested SEQ OF           LABEL     = 7reqs
                           STRUCTURE = SEQUENCE OF
                           CHILDREN  = { <7rqei, U 16 C,O,0> }

requested EntryInformation LABEL     = 7rqei
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7seqn, U  2 P,M,0> ,
                                         <7atts, U 17 C,O,0> }


(* Fetch *)

FetchArgument              LABEL     = 7afch
                           STRUCTURE = SET
                           CHILDREN  = { <7ibty, C  0 C,D,0> ,
                                         <7item, U  0 P,M,0> ,
                                         <7rqat, C  3 C,O,0> }

item                       LABEL     = 7item
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7selt, C  1 C,O,0> ,
                                         <7prec, C  2 C,O,0> }

precise                    LABEL     = 7prec
                           STRUCTURE = TAG
                           TAG       = (C 2 C)
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

FetchResult                LABEL     = 7rfch
                           STRUCTURE = SET
                           CHILDREN  = { <7entt, C  0 C,O,0> ,
                                         <7list, C  1 C,O,0> ,
                                         <7next, C  2 C,O,0> }

list TAG                   LABEL     = 7list
                           STRUCTURE = TAG
                           CHILDREN  = { <7liss, U 16 C,M,0> }

list SEQ OF                LABEL     = 7liss
                           STRUCTURE = SEQUENCE OF
                           CHILDREN  = { <7lseq, U  2 P,O,0> }

list SequenceNumber        LABEL     = 7lseq
                           STRUCTURE = INTEGER


(* Delete *)

DeleteArgument             LABEL     = 7adel
                           STRUCTURE = SET
                           CHILDREN  = { <7ibty, C  0 C,D,0> ,
                                         <7itms, U  0 P,M,0> }

items                      LABEL     = 7itms
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7selt, C  1 C,M,0> ,
                                         <7sqst, C  2 C,M,0> }

sequence-numbers TAG       LABEL     = 7sqst
                           STRUCTURE = TAG
                           TAG       = (C 2 C)
                           CHILDREN  = { <7sqss, U 17 C,M,0> }

sequence-numbers SET OF    LABEL     = 7sqss
                           STRUCTURE = SET OF
                           CHILDREN  = { <7sqpr, U  2 P,O,0> }

sequence-number (precise)  LABEL     = 7sqpr
                           STRUCTURE = INTEGER

DeleteResult               LABEL     = 7rdel
                           STRUCTURE = NULL


(* Register-MS *)

Register-MSArgument        LABEL     = 7areg
                           STRUCTURE = SET
                           CHILDREN  = { <7regt, C  0 C,O,0> ,
                                         <7drgt, C  1 C,O,0> ,
                                         <7ladt, C  2 C,O,0> ,
                                         <7fadt, C  3 C,O,0> ,
                                         <7ccrt, C  4 C,O,0> ,
                                         <7uslt, C  5 C,O,0> }

auto-action-reg TAG        LABEL     = 7regt
                           STRUCTURE = TAG
                           CHILDREN  = { <7regs, U 17 C,M,0> }

auto-action-reg SET OF     LABEL     = 7regs
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7aarg, U 16 C,O,0> }

auto-action-dereg TAG      LABEL     = 7drgt
                           STRUCTURE = TAG
                           CHILDREN  = { <7drgs, U 17 C,M,0> }

auto-action-dereg SET OF   LABEL     = 7drgs
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7aadr, U 16 C,O,0> }

AutoActionDeregistration   LABEL     = 7aadr
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7adty, U  6 P,M,0> ,
                                         <7drit, C  0 C,D,0> }

AutoActionDeregType        LABEL     = 7adty
                           STRUCTURE = OBJECT IDENTIFIER

de-registration-id TAG     LABEL     = 7drit
                           STRUCTURE = TAG
                           CHILDREN  = { <7drid, U  2 P,M,0> }

de-registration-id         LABEL     = 7drid
                           STRUCTURE = INTEGER

list-attribute-defaults    LABEL     = 7ladt
                           STRUCTURE = TAG
                           CHILDREN  = { <7ladf, U 17 C,M,0> }

fetch-attribute-defaults   LABEL     = 7fadt
                           STRUCTURE = TAG
                           CHILDREN  = { <7fadf, U 17 C,M,0> }

attribute-defaults (list)  LABEL     = 7ladf
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7laty, U  6 P,O,0> }

atttribute-type (list)     LABEL     = 7laty
                           STRUCTURE = OBJECT IDENTIFIER

attribute-defaults (fetch) LABEL     = 7fadf
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7faty, U  6 P,O,0> }

atttribute-type (fetch)    LABEL     = 7faty
                           STRUCTURE = OBJECT IDENTIFIER

change-credentials TAG     LABEL     = 7ccrt
                           STRUCTURE = TAG
                           CHILDREN  = { <7ccrs, U 16 C,M,0> }

change-credentials SEQ     LABEL     = 7ccrs
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <7ocrd, C  0 C,M,0> ,
                                         <7ncrd, C  1 C,M,0> }

old-credentials            LABEL     = 7ocrd
                           STRUCTURE = TAG
                           CHILDREN  = { <7cred, U  0 P,M,0> }

new-credentials            LABEL     = 7ncrd
                           STRUCTURE = TAG
                           CHILDREN  = { <7cred, U  0 P,M,0> }

user-security-labs TAG     LABEL     = 7uslt
                           STRUCTURE = TAG
                           CHILDREN  = { <7usls, U 17 C,M,0> }

user-security-labs SET OF  LABEL     = 7usls
                           STRUCTURE = SET OF
                           LIMIT     = 256
                           CHILDREN  = { <Xmslb, U 17 C,O,0> }

Register-MSResult          LABEL     = 7rreg
                           STRUCTURE = NULL


(* Alert *)

AlertArgument              LABEL     = 7alrt
                           STRUCTURE = SET
                           CHILDREN  = { <7alid, C  0 C,M,0> ,
                                         <7entt, C  2 C,O,0> }

alert-registration-id      LABEL     = 7alid
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

AlertResult                LABEL     = 7ralt
                           STRUCTURE = NULL


(*****************************************************************************)
(* Common abstract-operations arguments/results                              *)
(*****************************************************************************)

information-base-type      LABEL     = 7ibty
                           STRUCTURE = TAG
                           CHILDREN  = { <7infb, U  2 P,M,0> }

selector                   LABEL     = 7selt
                           STRUCTURE = TAG
                           TAG       = (C 1 C)
                           CHILDREN  = { <7selr, U 17 C,M,0> }

next                       LABEL     = 7next
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

count                      LABEL     = 7coun
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

span                       LABEL     = 7rspn
                           STRUCTURE = TAG
                           CHILDREN  = { <7span, U 16 C,M,0> }

requested-attributes       LABEL     = 7rqat
                           STRUCTURE = TAG
                           CHILDREN  = { <7ents, U 17 C,M,0> }

entry-information TAG      LABEL     = 7entt
                           STRUCTURE = TAG
                           CHILDREN  = { <7enti, U 16 C,M,0> }



(*****************************************************************************)
(* Abstract-errors                                                           *)
(*****************************************************************************)

(* Attribute Error *)

AttributeError             LABEL     = 7ater
                           STRUCTURE = SET
                           CHILDREN  = { <7pr1t, C  0 C,M,0> }

problems TAG               LABEL     = 7pr1t
                           STRUCTURE = TAG
                           CHILDREN  = { <7pr1s, U 17 C,M,0> }

problems SET OF            LABEL     = 7pr1s
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7po1s, U 17 C,O,0> }

problems SET               LABEL     = 7po1s
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> ,
                                         <7patt, C  1 C,M,0> ,
                                         <7pavt, C  2 C,O,0> }

problem TAG                LABEL     = 7prot
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }

type TAG                   LABEL     = 7patt
                           STRUCTURE = TAG
                           CHILDREN  = { <7atty, U  6 P,M,0>*}

value TAG                  LABEL     = 7pavt
                           STRUCTURE = TAG
                           CHILDREN  = { <7atvl, U  0 P,M,0> }


(* Auto Action Request Error *)

AutoActionRequestError     LABEL     = 7aaer
                           STRUCTURE = SET
                           CHILDREN  = { <7pr2t, C  0 C,M,0> }

problems TAG               LABEL     = 7pr2t
                           STRUCTURE = TAG
                           CHILDREN  = { <7pr2s, U 17 C,M,0> }

problems SET OF            LABEL     = 7pr2s
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7po2s, U 17 C,O,0> }

problems SET               LABEL     = 7po2s
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> ,
                                         <7paat, C  1 C,M,0> }

type TAG                   LABEL     = 7paat
                           STRUCTURE = TAG
                           CHILDREN  = { <7aaty, U  6 P,M,0> }


(* Delete Error *)

DeleteError                LABEL     = 7dler
                           STRUCTURE = SET
                           CHILDREN  = { <7pr3t, C  0 C,M,0> }

problems TAG               LABEL     = 7pr3t
                           STRUCTURE = TAG
                           CHILDREN  = { <7pr3s, U 17 C,M,0> }

problems SET OF            LABEL     = 7pr3s
                           STRUCTURE = SET OF
                           CHILDREN  = { <7po3s, U 17 C,O,0> }

problems SET               LABEL     = 7po3s
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> ,
                                         <7seqt, C  1 C,M,0> }

sequence-number TAG        LABEL     = 7seqt
                           STRUCTURE = TAG
                           CHILDREN  = { <7seqn, U  2 P,M,0> }


(* Fetch Restrictions Error *)

FetchRestrictionsError     LABEL     = 7frer
                           STRUCTURE = SET
                           CHILDREN  = { <7pr4t, C  0 C,M,0> }

problems TAG               LABEL     = 7pr4t
                           STRUCTURE = TAG
                           CHILDREN  = { <7pr4s, U 17 C,M,0> }

problems SET OF            LABEL     = 7pr4s
                           STRUCTURE = SET OF
                           LIMIT     = 1024
                           CHILDREN  = { <7po4s, U 17 C,O,0> }

problems SET               LABEL     = 7po4s
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  3 C,M,0> ,
                                         <7pres, U  0 P,M,0> }

restriction                LABEL     = 7pres
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7pctt, C  0 C,O,0> ,
                                         <7pmet, C  1 C,O,0> ,
                                         <7pclt, C  2 C,O,0> }

content-type TAG           LABEL     = 7pctt
                           STRUCTURE = TAG
                           CHILDREN  = { <7pcty, U 00 P,M,0> }

content-type               LABEL     = 7pcty
                           STRUCTURE = CHOICE
                           CHILDREN  = { <7pcti, A  6 P,O,1024>,
                                         <7pcto, U  6 P,O,0>   }

content-type (int)         LABEL     = 7pcti
                           STRUCTURE = INTEGER

content-type (objid)       LABEL     = 7pcto
                           STRUCTURE = OBJECT IDENTIFIER

MS-EITs                    LABEL     = 7pmet
                           STRUCTURE = TAG
                           CHILDREN  = { <7eits, U 17 C,M,0> }

content-length             LABEL     = 7pclt
                           STRUCTURE = TAG
                           CHILDREN  = { <Cintg, U  2 P,M,0> }


(* Invalid Parameters Error is Null *)


(* Range Error *)

RangeError                 LABEL     = 7rger
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> }


(* Sequence Number Error *)

SequenceNumberError        LABEL     = 7sner
                           STRUCTURE = SET
                           CHILDREN  = { <7pr7t, C  1 C,M,0> }

problems TAG               LABEL     = 7pr7t
                           STRUCTURE = TAG
                           CHILDREN  = { <7pr7s, U 17 C,M,0> }

problems SET OF            LABEL     = 7pr7s
                           STRUCTURE = SET OF
                           CHILDREN  = { <7po7s, U 17 C,O,0> }

problems SET               LABEL     = 7po7s
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> ,
                                         <7seqt, C  1 C,M,0> }

(* Service Error *)

ServiceError               LABEL     = 7sver
                           STRUCTURE = SET
                           CHILDREN  = { <7prot, C  0 C,M,0> }


(* Nodes from other templates needed with different tags *)

Message delivery envelope  LABEL     = 7mdnv
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <Mmtid, A  4 C,M,0> ,
                                         <3mdtm, U 23 P,M,0> ,
                                         <7omdf, U 17 C,D,0> }

OtherMessageDeliveryFields LABEL     = 7omdf
                           STRUCTURE = SET
                           CHILDREN  = { <Mdcnt, U  0 P,M,0> ,
                                         <Morig, A  0 C,M,0> ,
                                         <Meits, C  1 C,O,0> ,
                                         <Mprio, A  7 P,D,0> ,
                                         <3dflg, C  2 P,O,16>,
                                         <3orcp, C  3 C,O,0> ,
                                         <3trcp, C  4 C,M,0> ,
                                         <Mircp, C  5 C,O,0> ,
                                         <Mceit, C  6 C,O,0> ,
                                         <3mstm, C  7 P,M,0> ,
                                         <Mcnti, C  8 P,O,16>,
                                         <7mdxf, C  9 C,D,0>  }

MsgDeliveryExtensionFields LABEL     = 7mdxf
                           STRUCTURE = SET OF
                           LIMIT     = 19
                           CHILDREN  = { <7mdxt, U  0 P,O,0>  }

MessageDeliveryExtensions  LABEL     = 7mdxt
                           STRUCTURE = ANY
                           CHILDREN  = {}

Report delivery envelope   LABEL     = 7rdnv
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <Mmtid, A  4 C,M,0> D,
                                         <Mcnti, A 10 P,O,16>D,
                                         <Mrcnt, U  0 P,O,0> D,
                                         <Meits, A  5 C,O,0> D,
                                         <7rdxf, C  1 C,D,0> D,
                                         <7rrcp, U 16 C,M,0> D }

MsgDeliveryExtensionFields LABEL     = 7rdxf
                           STRUCTURE = SET OF
                           LIMIT     = 19
                           CHILDREN  = { <7rdxt, U  0 P,O,0>  }

MessageDeliveryExtensions  LABEL     = 7rdxt
                           STRUCTURE = ANY
                           CHILDREN  = {}

SEQ OF PerReportRcptFields LABEL     = 7rrcp
                           STRUCTURE = SEQUENCE OF
                           LIMIT     = 32767
                           CHILDREN  = { <7rrpf, U  0 P,O,0> }

PerReportRecipientFields   LABEL     = 7rrpf
                           STRUCTURE = ANY
                           CHILDREN  = { }

ContentIdentifier          LABEL     = 7cnti
                           STRUCTURE = PRINTABLE STRING
                           TAG       = (A 10 P)

MTSIdentifier              LABEL     = 7mtid
                           STRUCTURE = SEQUENCE
                           TAG       = (A 4 C)
                           CHILDREN  = { <Mgbid, A  3 C,M,0> D,
                                         <Mlcid, U 22 P,M,32>  }

Priority                   LABEL     = 7prio
                           STRUCTURE = INTEGER
                           TAG       = (A 7 P)

(* Auto-Forward Registration Parameter *)

AutoForwardRegistrationPar LABEL     = 7afrp
                           STRUCTURE = SET
                           CHILDREN  = { <7af0t, C  0 C,O,0> ,
                                         <7af1t, C  1 C,O,0> ,
                                         <7af2t, C  2 C,O,0> ,
                                         <7af3t, C  3 C,O,0>  }

AutoForwardFilterTag       LABEL     = 7af0t
                           STRUCTURE = TAG
                           TAG       = (C 0 C)
                           CHILDREN  = { <7filt, U  0 P,M,0>  }

AutoForwardArgumentsTag    LABEL     = 7af1t
                           STRUCTURE = TAG
                           TAG       = (C 1 C)
                           CHILDREN  = { <7afar, U 17 C,M,0>  }

AutoForwardDeleteTag       LABEL     = 7af2t
                           STRUCTURE = TAG
                           TAG       = (C 2 C)
                           CHILDREN  = { <7afdl, U  1 P,M,0>  }

AutoForwardOtherParmsTag   LABEL     = 7af3t
                           STRUCTURE = TAG
                           TAG       = (C 3 C)
                           CHILDREN  = { <7afot, U  4 S,M,0>  }

AutoForwardArguments       LABEL     = 7afar
                           STRUCTURE = SET
                           CHILDREN  = { <Morig, A  0 C,M,0> ,
                                         <Mcnti, A 10 P,O,16>,
                                         <7prio, A  7 P,O,0> ,
                                         <Mpmsg, A  8 P,O,0> ,
                                         <Mddlv, C  0 P,O,0> ,
                                         <3pmxf, C  2 C,D,0> ,
                                         <3srcp, C  1 C,M,0>  }

AutoForwardDeleteAfter     LABEL     = 7afdl
                           STRUCTURE = BOOLEAN

AutoForwardOtherParms      LABEL     = 7afot
                           STRUCTURE = OCTET STRING

(* Auto-Alert Registration Parameter *)

AutoAlertRegistrationPar   LABEL     = 7aarp
                           STRUCTURE = SET
                           CHILDREN  = { <7aa0t, C  0 C,O,0> ,
                                         <7aa1t, C  1 C,O,0> ,
                                         <7aa2t, C  2 C,O,0>  }

AutoAlertFilterTag         LABEL     = 7aa0t
                           STRUCTURE = TAG
                           TAG       = (C 0 C)
                           CHILDREN  = { <7filt, U  0 P,M,0>  }

AutoAlertAddressesTag      LABEL     = 7aa1t
                           STRUCTURE = TAG
                           TAG       = (C 1 C)
                           CHILDREN  = { <7aaaz, U 16 C,M,0>  }

AutoAlertRequestedTag      LABEL     = 7aa2t
                           STRUCTURE = TAG
                           TAG       = (C 2 C)
                           CHILDREN  = { <7ents, U 17 C,M,0>  }

AutoAlertAddresses         LABEL     = 7aaaz
                           STRUCTURE = SEQUENCE OF
                           CHILDREN  = { <7aaad, U 16 C,M,0>  }

AutoAlertAddress           LABEL     = 7aaad
                           STRUCTURE = SEQUENCE
                           CHILDREN  = { <Cextn, U  8 C,M,0> ,
                                         <7aaql, U  4 P,O,0>  }

AutoAlertQualifier         LABEL     = 7aaql
                           STRUCTURE = OCTET STRING
!
